var yeoman = require('yeoman-generator')
var yosay = require('yosay')

var GithubGenerator = yeoman.generators.Base.extend({
  init: function () {
    this.pkg = require('../package.json')

    // Have Yeoman greet the user.
    this.log(yosay('Welcome to the marvelous GitHub generator!'))
    this.currentYear = new Date().getFullYear()
  },

  askForGitHubDetails: function () {
    var done = this.async()

    var prompts = [{
      type: 'input',
      name: 'fullName',
      message: 'What is your full name?',
      required: true,
      store: true,
      default: 'John Doe'
    }, {
      type: 'input',
      name: 'githubUsername',
      message: 'What is your GitHub user name?',
      required: true,
      store: true,
      default: 'someuser'
    }, {
      type: 'input',
      name: 'githubProject',
      message: 'What is the name of your GitHub project?',
      required: true,
      default: 'someproject'
    }]

    this.prompt(prompts, function (props) {
      this.fullName = props.fullName
      this.githubUsername = props.githubUsername
      this.githubProject = props.githubProject

      done()
    }.bind(this))
  },

  askForIntegrations: function () {
    var done = this.async()

    var prompts = [{
      type: 'confirm',
      name: 'isCoverallsEnabled',
      message: 'Would you like to enable the Coveralls badge?',
      store: true,
      default: true
    }, {
      type: 'confirm',
      name: 'isTravisEnabled',
      message: 'Would you like to enable the Travis badge?',
      store: true,
      default: true
    }]

    this.prompt(prompts, function (props) {
      this.isCoverallsEnabled = props.isCoverallsEnabled
      this.isTravisEnabled = props.isTravisEnabled

      done()
    }.bind(this))
  },

  enforceFolderName: function () {
    this.destinationRoot(this.githubProject)
  },

  app: function () {
    this.copy('CHANGELOG.md', 'CHANGELOG.md')
    this.copy('CONTRIBUTING.md', 'CONTRIBUTING.md')
    this.copy('_editorconfig', '.editorconfig')
    this.copy('_gitattributes', '.gitattributes')
    this.copy('logo.svg', 'logo.svg')

    this.template('LICENSE.txt', 'LICENSE.txt')
    this.template('README.md', 'README.md')
  }
})

module.exports = GithubGenerator
